==> kendo-layout-vue-wrapper-2020.3.1021.tgz: package/docs/splitter/index.md <==
---
title: Overview
page_title: Splitter Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI Splitter wrapper for Vue delivers and use the component in Vue projects."
slug: overview_splitter
position: 0
---

# Splitter Overview

The Splitter provides a dynamic layout of resizable and collapsible panes.

The component converts the children of an HTML element into an interactive layout and adds resize and collapse handles depending on its configuration. The vertical and horizontal orientation of the Splitter can be combined to build complex layouts.

The Splitter wrapper for Vue is a client-side wrapper for the [Kendo UI Splitter](https://docs.telerik.com/kendo-ui/controls/layout/splitter/overview) widget.

## Basic Usage

The following example demonstrates the Splitter in action.

{% meta height:380 %}
```html-preview    
<div id="vueapp">
    <kendo-splitter :orientation="'vertical'">
        <div>
			<kendo-splitter  :orientation="'horizontal'">
				<div>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. </div>
				<div>Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</div>
                <div>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. </div>
			</kendo-splitter>
		</div>
        <div>
            <kendo-splitter  :orientation="'vertical'">
				<div>News</div>
				<div>Weather forecast</div>               
			</kendo-splitter>
        </div>
    </kendo-splitter>
</div>
```
```js  
    Vue.use(LayoutInstaller);
    new Vue({ el: '#vueapp'	})
```
{% endmeta %}

## Functionality and Features

* [Loading content with AJAX]({% slug loading_content_ajax_splitter %})
* [Keyboard navigation]({% slug keyboard_navigation_splitter %})
* [RTL support]({% slug rtl_support_splitter %})

## Suggested Links

* [Kendo UI Splitter for jQuery](https://docs.telerik.com/kendo-ui/controls/layout/splitter/overview)
* [API Reference of the Splitter](https://docs.telerik.com/kendo-ui/api/javascript/ui/splitter)

==> kendo-layout-vue-wrapper-2022.1.412-dev.502.tgz: package/docs/splitter/index.md <==
---
title: Overview
page_title: Splitter Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI Splitter wrapper for Vue delivers and use the component in Vue projects."
slug: overview_splitter_wrapper
position: 0
---

<WrapperBanner link="/kendo-vue-ui/components/layout/splitter"></WrapperBanner>    

# Splitter Overview

The Splitter provides a dynamic layout of resizable and collapsible panes.

The component converts the children of an HTML element into an interactive layout and adds resize and collapse handles depending on its configuration. The vertical and horizontal orientation of the Splitter can be combined to build complex layouts.

The Splitter wrapper for Vue is a client-side wrapper for the [Kendo UI Splitter](https://docs.telerik.com/kendo-ui/controls/layout/splitter/overview) widget.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the Splitter in action.

{% meta height:380 %}
{% embed_file splitter/basic/main.vue preview %}
{% embed_file splitter/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Loading content with AJAX]({% slug loading_content_ajax_splitter %})
* [Keyboard navigation]({% slug keyboard_navigation_splitter_wrapper %})
* [RTL support]({% slug rtl_support_splitter %})

## Suggested Links

* [Kendo UI Splitter for jQuery](https://docs.telerik.com/kendo-ui/controls/layout/splitter/overview)
* [API Reference of the Splitter](https://docs.telerik.com/kendo-ui/api/javascript/ui/splitter)
